syndicate = {
    "resource_type": "dynamodb_table",
    "hash_key_name": "id",
    "hash_key_type": "S",
    "sort_key_name": "name",
    "sort_key_type": "S",
    "read_capacity": 2,
    "write_capacity": 1,
    "indexes": {
        'a': 'sda'
    }
}
aws = {
    "resource_type": "dynamodb_table",
    "hash_key_name": "ids",
    "hash_key_type": "B",
    "sort_key_name": "name",
    "sort_key_type": "B",
    "read_capacity": 2,
    "write_capacity": 1,
    "indexes": {
        'b': 'sda'
    }

}

errors_set = set(syndicate.items()) ^ set(aws.items())  # get difference between two dicts
keys_with_errors = {i[0] for i in errors_set}
print(keys_with_errors)
result = {}
for key in keys_with_errors:
    expected_value = syndicate.get(key)
    actual_value = aws.get(key)
    result[key] = (expected_value, actual_value)

print(errors_set)
print(result)


INSTANCE_TYPES = ('r3', 'r4', 'm6g.xlarge', 'r5', 'optimal', 'r5d.24xlarge', 'm5n', 'm3.xlarge',
                  'r4.16xlarge', "r5a.2xlarge", 'c6g.4xlarge', 'm5.xlarge', 'c5a.2xlarge', 'r6g.4xlarge',
                  'r6g.16xlarge', 'i3.4xlarge', 'z1d.3xlarge', 'm5n.24xlarge', 'a1.medium', 'r5b.16xlarge',
                  'm5.large', 'c5d.large', 'm6g.2xlarge', 'm5dn.2xlarge', 'm6g', 'c5.large', 'g4dn.2xlarge',
                  'c5.metal', 'i3en.6xlarge', 'inf1.2xlarge', 'm5.2xlarge', 'r6g.xlarge', 'c3', 'c4', 'c5',
                  'm5dn.8xlarge', 'r5n.16xlarge', 'm6g.8xlarge', 'c5a.8xlarge', 'i2.xlarge', 'm5d.12xlarge',
                  'm5.metal', 'c5d.metal', 'm4.4xlarge', 'm5.12xlarge', 'inf1', 'm6g.12xlarge', 'r5n.4xlarge',
                  'c4.large', 'c5d.2xlarge', 'z1d', 'd2', 'r5d.2xlarge', 'r5.xlarge', 'r5b.24xlarge', 'c4.4xlarge',
                  'c4.xlarge', 'c6g.large', 'r4.8xlarge', 'm5d.xlarge', 'm5.8xlarge', 'c5.2xlarge', 'g3.8xlarge',
                  'c5n.9xlarge', 'c5n.2xlarge', 'r4.2xlarge', 'm5zn.6xlarge', 'm5zn.12xlarge', 'm5d.4xlarge',
                  'c6g.metal', 'c5a', 'c5d', 'c5d.xlarge', 'm5n.16xlarge', 'r5a.8xlarge', 'c5a.16xlarge', 'c5n',
                  'r3.4xlarge', 'c6g.12xlarge', 'r5b.xlarge', 'x1e.xlarge', 'c5.12xlarge', 'r5d.xlarge', 'm6g.large',
                  'i3en.xlarge', 'r5n.2xlarge', 'p2.16xlarge', 'c6g', 'a1.metal', 'r5dn.8xlarge', 'x1.16xlarge',
                  'r5n.12xlarge', 'm5a.4xlarge', 'c5n.metal', 'c5.xlarge', 'c5n.4xlarge', 'g2', 'm5d.24xlarge', 'g3',
                  'm5zn', 'c5.9xlarge', 'r5d.8xlarge', 'd2.2xlarge', 'r5.2xlarge', 'x1', 'i3en.2xlarge', 'a1.large',
                  'r5b', 'r5a', 'r5d', 'm5n.2xlarge', 'i2.8xlarge', 'z1d.12xlarge', 'm6g.metal', 'm5dn.4xlarge',
                  'r3.xlarge', 'r5n', 'x1e', 'm5dn.large', 'm5.24xlarge', 'g4dn.12xlarge', 'c6g.2xlarge',
                  'r5d.12xlarge', 'z1d.xlarge', 'm3.2xlarge', 'i3en.24xlarge', 'm5ad.8xlarge', 'i3en.3xlarge',
                  'c5d.12xlarge', 'r5a.12xlarge', 'r5a.4xlarge', 'm5n.xlarge', 'i3.large', 'm3.medium', 'c5a.12xlarge',
                  'r6g', 'c5n.xlarge', 'i3.metal', 'i3.16xlarge', 'r6g.12xlarge', 'c5n.large', 'm4.16xlarge', 'i2',
                  'i3', 'x1e.16xlarge', 'c3.2xlarge', 'r5.24xlarge', 'c6g.xlarge', 'r5.4xlarge', 'm5dn.16xlarge',
                  'p2.8xlarge', 'g3.4xlarge', 'r3.8xlarge', 'm5d.8xlarge', 'c5a.xlarge', 'm5dn.metal', 'c5a.large',
                  'm5ad.12xlarge', 'm4.xlarge', 'g2.2xlarge', 'c3.4xlarge', 'm5n.4xlarge', 'm5dn.12xlarge',
                  'c4.2xlarge', 'm5a.24xlarge', 'g2.8xlarge', 'c6g.16xlarge', 'r5.large', 'z1d.large', 'm5n.large',
                  'r3.2xlarge', 'm5d.2xlarge', 'm5zn.large', 'i3en', 'x1e.8xlarge', 'g4dn.4xlarge', 'r5d.4xlarge',
                  'c5d.24xlarge', 'r5d.metal', 'm6g.medium', 'x1.32xlarge', 'g4dn.xlarge', 'a1.2xlarge', 'r5b.8xlarge',
                  'r6g.medium', 'm5ad.xlarge', 'c4.8xlarge', 'm5a.8xlarge', 'c5d.9xlarge', 'm5ad.4xlarge', 'p2.xlarge',
                  'm5n.metal', 'g3s', 'r6g.large', 'p3dn.24xlarge', 'm5ad.24xlarge', 'c5.24xlarge', 'r5.16xlarge',
                  'g4dn.metal', 'm5a.2xlarge', 'r4.xlarge', 'm5ad.large', 'i3en.metal', 'r6g.2xlarge', 'p3.2xlarge',
                  'm5d.16xlarge', 'm5a.xlarge', 'm5zn.xlarge', 'r5dn.12xlarge', 'm5dn.24xlarge', 'i3.2xlarge', 'm3',
                  'r6g.8xlarge', 'm4', 'm5', 'm5dn.xlarge', 'm5a.12xlarge', 'r5d.large', 'z1d.6xlarge', 'c3.large',
                  'i2.4xlarge', 'm5zn.metal', 'z1d.metal', 'r5dn.24xlarge', 'inf1.24xlarge', 'r6g.metal', 'i3.xlarge',
                  'p3.16xlarge', 'd2.4xlarge', 'r5a.16xlarge', 'r5dn.4xlarge', 'm5.16xlarge', 'c6g.medium',
                  'i3en.large', 'm5d.large', 'r5a.xlarge', 'r5.8xlarge', 'm4.10xlarge', 'c5.4xlarge', 'r5dn.2xlarge',
                  'r5a.24xlarge', 'i3.8xlarge', 'c6g.8xlarge', 'm4.2xlarge', 'inf1.6xlarge', 'r5b.large', 'r5b.4xlarge',
                  'm5zn.2xlarge', 'r5n.metal', 'd2.xlarge', 'm5a.large', 'd2.8xlarge', 'c5n.18xlarge', 'm6g.4xlarge',
                  'r5n.xlarge', 'r5b.12xlarge', 'm5n.8xlarge', 'g3.16xlarge', 'c5.18xlarge', 'p3.8xlarge',
                  'm6g.16xlarge', 'r4.4xlarge', 'i3en.12xlarge', 'g4dn.16xlarge', 'x1e.4xlarge', 'r5d.16xlarge',
                  'm4.large', 'm5ad', 'g4dn.8xlarge', 'r5dn.large', 'r5n.24xlarge', 'p3dn', 'i2.2xlarge', 'm5dn',
                  'm5n.12xlarge', 'p2', 'r5.metal', 'p3', 'c5d.18xlarge', 'x1e.2xlarge', 'r5dn.xlarge', 'c5a.4xlarge',
                  'm5d.metal', 'a1.xlarge', 'r3.large', 'm5ad.2xlarge', 'x1e.32xlarge', 'z1d.2xlarge', 'g3s.xlarge',
                  'm5a.16xlarge', 'r5dn.metal', 'c3.xlarge', 'r5b.2xlarge', 'g4dn', 'r5.12xlarge', 'r4.large',
                  'c5a.24xlarge', 'm3.large', 'm5ad.16xlarge', 'a1', 'r5b.metal', 'r5n.8xlarge', 'a1.4xlarge',
                  'r5dn.16xlarge', 'm5a', 'r5a.large', 'm5zn.3xlarge', 'r5dn', 'c5d.4xlarge', 'r5n.large', 'c3.8xlarge',
                  'inf1.xlarge', 'm5d', 'm5.4xlarge')
